==> qtcreator_3.2.1+dfsg.orig.tar.xz: qt-creator-opensource-src-3.2.1/src/plugins/remotelinux/remotelinuxcustomcommanddeployservice.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/
#ifndef REMOTELINUXCUSTOMCOMMANDDEPLOYSERVICE_H
#define REMOTELINUXCUSTOMCOMMANDDEPLOYSERVICE_H

#include "abstractremotelinuxdeployservice.h"

namespace RemoteLinux {
namespace Internal { class RemoteLinuxCustomCommandDeployservicePrivate; }

class REMOTELINUX_EXPORT RemoteLinuxCustomCommandDeployService
    : public AbstractRemoteLinuxDeployService
{
    Q_OBJECT
public:
    explicit RemoteLinuxCustomCommandDeployService(QObject *parent = 0);
    ~RemoteLinuxCustomCommandDeployService();

    void setCommandLine(const QString &commandLine);

    bool isDeploymentNecessary() const { return true; }
    bool isDeploymentPossible(QString *whyNot = 0) const;

protected:
    void doDeviceSetup() { handleDeviceSetupDone(true); }
    void stopDeviceSetup() { handleDeviceSetupDone(false); }
    void doDeploy();
    void stopDeployment();

private slots:
    void handleStdout();
    void handleStderr();
    void handleProcessClosed(int exitStatus);

private:
    Internal::RemoteLinuxCustomCommandDeployservicePrivate *d;
};

} // namespace RemoteLinux

#endif // REMOTELINUXCUSTOMCOMMANDDEPLOYSERVICE_H

==> qtcreator_4.3.1.orig.tar.xz: qt-creator-opensource-src-4.3.1/src/plugins/remotelinux/remotelinuxcustomcommanddeployservice.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "abstractremotelinuxdeployservice.h"

namespace RemoteLinux {
namespace Internal { class RemoteLinuxCustomCommandDeployservicePrivate; }

class REMOTELINUX_EXPORT RemoteLinuxCustomCommandDeployService
    : public AbstractRemoteLinuxDeployService
{
    Q_OBJECT
public:
    explicit RemoteLinuxCustomCommandDeployService(QObject *parent = 0);
    ~RemoteLinuxCustomCommandDeployService();

    void setCommandLine(const QString &commandLine);

    bool isDeploymentNecessary() const { return true; }
    bool isDeploymentPossible(QString *whyNot = 0) const;

protected:
    void doDeviceSetup() { handleDeviceSetupDone(true); }
    void stopDeviceSetup() { handleDeviceSetupDone(false); }
    void doDeploy();
    void stopDeployment();

private:
    void handleStdout();
    void handleStderr();
    void handleProcessClosed(int exitStatus);

    Internal::RemoteLinuxCustomCommandDeployservicePrivate *d;
};

} // namespace RemoteLinux
